package controller

import (
	"Panel_development/app/e"
	"Panel_development/app/model"
	"Panel_development/app/service"
	"Panel_development/unity"
	"github.com/gin-gonic/gin"
	"github.com/go-playground/validator/v10"
	"strconv"
)

var ComponentClassify service.ComponentClassify = &model.ComponentClassify{}

// GetComponentClassify 获取组件分类
func GetComponentClassify(c *gin.Context) {
	classify, err := ComponentClassify.GetComponentClassify()
	if err != nil {
		e.ResponseWithMsg(c, e.ERROR, err.Error())
	} else {
		e.ResponseSuccess(c, classify)
	}
}

// AddComponentClassify 添加组件分类
func AddComponentClassify(c *gin.Context) {
	var cclass model.ComponentClassify
	err := c.ShouldBindJSON(&cclass)
	if err != nil {
		e.ResponseWithMsg(c, e.JSONParsingFailed, e.JSONParsingFailed.GetMsg())
		return
	}
	err = validator.New().Struct(&cclass)
	if err != nil {
		e.ResponseWithMsg(c, e.ERROR, err.Error())
	} else {
		cc, err := ComponentClassify.AddComponentClassify(cclass)
		if err != nil {
			e.ResponseWithMsg(c, e.ERROR, err.Error())
		} else {
			e.ResponseSuccess(c, cc)
		}
	}
}

// DeleteComponentClassify 删除组件分类
func DeleteComponentClassify(c *gin.Context) {
	s := c.Query("id")
	validate := validator.New()
	err := validate.Var(s, "required,numeric")
	if err != nil {
		e.ResponseWithMsg(c, e.ERROR, "id不能为空")
	}
	atoi, _ := strconv.Atoi(s)
	_, err = unity.DeleteById(atoi, model.ComponentClassify{})
	if err != nil {
		e.ResponseWithMsg(c, e.DELETEFAIL, e.DELETEFAIL.GetMsg())
	} else {
		e.ResponseSuccess(c, nil)
	}
}

// UpdateComponentClassify 更新组件分类
func UpdateComponentClassify(c *gin.Context) {
	var componentClass model.ComponentClassify
	s := c.Query("id")
	err := c.ShouldBindJSON(&componentClass)
	if err != nil {
		e.ResponseWithMsg(c, e.JSONParsingFailed, e.JSONParsingFailed.GetMsg())
		return
	}
	validate := validator.New()
	err = validate.Var(s, "required,numeric")
	if err != nil {
		e.ResponseWithMsg(c, e.ERROR, "id不能为空")
		return
	}
	atoi, _ := strconv.Atoi(s)
	id, err := unity.UpdateById(atoi, &componentClass)
	if err != nil {
		e.ResponseWithMsg(c, e.ERROR, err.Error())
		return
	}
	e.ResponseSuccess(c, id)
}
